CHANGES
---------------------------------

v0.0.1,  2014-03-05 -- Initial release.

v0.1.2,  2014-03-25 -- Deployment ready.

v0.1.19, 2014-03-26 -- Multiple fixes: non-restful mode, README, PUT/DELETE actions, error handling
